@@ -238,7 +238,6 @@ int put_px_head(pxdoc_t *pxdoc, pxhead_t *pxh, pxstream_t *pxs) {
 	int nullint = 0;
 	int i, len;
 	int sumfieldlen;   /* sum of all field name length include the 0 */
-	char *basehead;
 	int base, offset, dataheadoffset;
 	short int tmp;
 	int isindex;
@@ -248,7 +247,6 @@ int put_px_head(pxdoc_t *pxdoc, pxhead_t *pxh, pxstream_t *pxs) {
 	memset(&pxhead, 0, sizeof(pxhead));
 	memset(&pxdatahead, 0, sizeof(pxdatahead));
 
-	basehead = (char *) &pxhead;
 	isindex = !((pxh->px_filetype == pxfFileTypIndexDB) ||
 		        (pxh->px_filetype == pxfFileTypNonIndexDB) ||
 		        (pxh->px_filetype == pxfFileTypNonIncSecIndex) ||
@@ -288,8 +286,8 @@ int put_px_head(pxdoc_t *pxdoc, pxhead_t *pxh, pxstream_t *pxs) {
 			 * In several files it was just 12 in .DB and 17 in .PX files. */
 			put_short_le((char *)&pxhead.unknown12x13, 12);
 			put_short_le((char *)&pxhead.primaryKeyFields, pxh->px_primarykeyfields);
-			put_long_le((char *)&pxhead.primaryIndexWorkspace, (long) ((size_t)basehead-100));  /* just to set a value */
-			put_long_le((char *)&pxhead.unknownPtr1A, (long) ((size_t)basehead-500));  /* just to set a value */
+			put_long_le((char *)&pxhead.primaryIndexWorkspace, -100);  /* just to set a value */
+			put_long_le((char *)&pxhead.unknownPtr1A, -500);  /* just to set a value */
 			break;
 		case pxfFileTypPrimIndex:
 			put_short_le((char *)&pxhead.unknown12x13, 17);
@@ -322,8 +320,8 @@ int put_px_head(pxdoc_t *pxdoc, pxhead_t *pxh, pxstream_t *pxs) {
 		dataheadoffset = 0x58;
 	}
 	/* All the pointers, though we probably don't need them for a valid file */
-	put_long_le((char *)&pxhead.fldInfoPtr, (long) ((size_t)basehead+dataheadoffset));
-	put_long_le((char *)&pxhead.tableNamePtrPtr, (long) ((size_t)basehead+dataheadoffset+pxh->px_numfields*2));
+	put_long_le((char *)&pxhead.fldInfoPtr, dataheadoffset);
+	put_long_le((char *)&pxhead.tableNamePtrPtr, dataheadoffset+pxh->px_numfields*2);
 	switch(pxh->px_fileversion) {
 		case 70:
 			pxhead.fileVersionID = 0x0C;
@@ -434,7 +432,7 @@ int put_px_head(pxdoc_t *pxdoc, pxhead_t *pxh, pxstream_t *pxs) {
 	 * with numfields fields specifications (each 2 Bytes), followed
 	 * by this pointer (tableNamePtr) and numfield pointers to the
 	 * field names. */
-	put_long_le((char *)&ptr, (long) ((size_t)basehead+dataheadoffset+pxh->px_numfields*(2+4)+4));
+	put_long_le((char *)&ptr, dataheadoffset+pxh->px_numfields*(2+4)+4);
 	if(pxdoc->write(pxdoc, pxs, 4, &ptr) < 1) {
 		px_error(pxdoc, PX_RuntimeError, _("Could not write pointer to tablename."));
 		return -1;
@@ -444,7 +442,7 @@ int put_px_head(pxdoc_t *pxdoc, pxhead_t *pxh, pxstream_t *pxs) {
 	 * numfields sizeof(* Fieldname) + sizeof(* Tablename) + strlen(tablename)
 	 */
 	if(!isindex) {
-		base = (int) (size_t)basehead+dataheadoffset+pxh->px_numfields*(2+4)+4+tablenamelen;
+	  base = dataheadoffset+pxh->px_numfields*(2+4)+4+tablenamelen;
 		pxf = pxh->px_fields;
 		offset = 0;
 		for(i=0; i<pxh->px_numfields; i++, pxf++) {
